-- Daily Task zone, location and reputation commands
-- coding: utf-8 'ä

DTZ_Command = Turbine.ShellCommand()

function DTZ_Command:Execute( command,args )
    if args=="" then
        printh("Zones with Task Boards:")
		local ix = Vinny.Common.Sort(DT_Data.zone)
        for i,name in ipairs(ix) do
			local locs = ""
			for brd in pairs(DT_Data.zone[name]) do
			    if locs=="" then locs = brd else locs = locs..', '..brd end
			end
            Turbine.Shell.WriteLine(string.format("%2d %s: %s",i,name,locs))
        end
        return
    end
	print(help_text)
end

Turbine.Shell.AddCommand( "dtz",DTZ_Command )

-- Daily Task location command

DTL_Command = Turbine.ShellCommand()

function DTL_Command:Execute( command,args )
	local rc = args:upper()
	local fname = DT_Data.rep[rc]
	if fname then
		printh("Reputation locations for "..fname..':')
        for name,data in pairs(DT_Data.loc) do
			if data.rep==rc then print(name.." in "..data.zone) end
		end
		return
	end
	local str = "Task Board Locations"
    if args~="" then
		if not DT_Data.zone[args] then Vinny.Common.Help(help,command) return end
		str = str.." in "..args
	end
    printh(str..":")
	local ix = Vinny.Common.Sort(DT_Data.loc)
    for i,name in ipairs(ix) do
		local data = DT_Data.loc[name]
		if args=="" or args==data.zone then
			local loc = data.loc
			if args=="" then loc = loc.." ("..data.zone..")" end
			print(string.format("%s(%s) @ %s",name,data.rep,loc))
		end
    end
end

Turbine.Shell.AddCommand( "dtl",DTL_Command )

-- Daily Task reputation commands

DTR_Command = Turbine.ShellCommand()
local pix,pi,rs
local function pix_comp(a,b)
	return DT_Settings.player[a]>DT_Settings.player[b]
end
local function pfind(loc,lv)
	if not DT_Data.rz[loc] and DT_Data.loc[loc].nc then return end
	if DT_Data.moriax[loc] then return end
	local lt = DT_Data.loc[loc]
	local rep = DT_Data.rz[loc] or lt.rep
	local c,ll,rep = DT_Lvl(C,lv,rep)
	if rep=="--" then return end
	if rs and rs~="--" and rep~=rs then return end
	for i,name in ipairs(pix) do
		if DT_Settings.rep[name] and DT_Settings.rep[name][rep]==nil then
		  if not pi or pi.i>i or pi.i==i and pi.ll<ll then
			pi = {i=i, rep=rep, loc=loc, ll=ll, bl=DT_Settings.player[name]<ll }
		  end
		  return
		end
	end
end

function DTR_Command:Execute( command,args )
	if args=="?" then Vinny.Common.Help(help,command) return end
    if args=="" then
      	printh("Reputation factions:")
		local sk = Turbine.UI.Control.IsShiftKeyDown()
		for i,id in ipairs(Vinny.Common.Sort(DT_Data.rep)) do
			local name,l='',0
			if id~="--" then
				for pn,pl in pairs(DT_Settings.player) do
					if pl>l and not (DT_Settings.rep[pn] and DT_Settings.rep[pn][id]~=nil) then
						l,name = pl,pn
					end
				end
			end
			if l>0 then name = ", ("..name..")" end
			local tst = DT_Data.tsrep[id]
			if sk and tst then
				local fl = tst[CTS]
				if fl then name = ', <rgb=#00FF00>'..CTS..'='..fl.."</rgb>"..name end
				local fl = tst.R
				if fl then name = ', <rgb=#00FF00>R='..fl.."</rgb>"..name end
			end
			print(string.format("%s: %s%s", id, DT_Data.rep[id], name))
		end
    	return
	end
	if not pix then	-- Build sorted player list?
		pix = Vinny.Common.Sort(DT_Settings.player, pix_comp)
	end
    if args=="list" then
		rs = DT_Rwindow.rep
		local sk = Turbine.UI.Control.IsShiftKeyDown()
		local str = rs=="++" and "" or " with "..DT_Data.rep[rs]
    	printh("Kindred reputation"..str..":")
    	for i,name in ipairs(pix) do
			local str,rt = "", DT_Settings.rep[name]
			if rt and rs=="++" then
				for i,rc in ipairs(Vinny.Common.Sort(rt)) do
					if str~="" then str = str..", " end
					if not rt[rc] and sk then 
						str = str.."<rgb=#FF00FF>"..rc.."</rgb>"
					else str = str..rc end
				end
			elseif rt and next(rt) then
				if rt[rs] then str = "<rgb=#00FF00>"..rs.."</rgb>" 
				elseif sk then
					if rt[rs]==false then str = "<rgb=#FFFF00>"..rs.."</rgb>" 
					else str = "<rgb=#FF0000>"..rs.."</rgb>" end
				end
			elseif rs=="--" then str = " " end
			if str~="" then print(string.format("%s: %s",name,str)) end
		end
		return
	end
    if args=="top" then
		  rs = DT_Rwindow.rep~="++" and DT_Rwindow.rep
		  local str = rs and " for "..DT_Data.rep[rs] or ""
		  if rs=="--" then printh("Items with no usable rep:")
		  else printh("Top Reputation item uses"..str..":") end
		  local ti = DT_Backpack()
		  for i,name in ipairs(Vinny.Common.Sort(ti)) do
		    local id,item = DT_Find(name)
		    if id then
			  pi = nil
			  for loc,lv in pairs(item.L) do
				  pfind(loc,lv)
			  end
			  if rs=="--" then
				  if not pi then
					  local xname = string.format(xlink,id,item.N)
					  local nbr = string.format("%2i ",ti[name].n)
					  print(nbr..xname)
				  end
			  elseif pi then
				  local xname = string.format(xlink,id,item.N)
				  local nbr = string.format("%2i ",ti[name].n)
				  local pn = pix[pi.i]
				  local clr = pi.bl and red or pn==pname and grn or yel
				  pn = " <rgb=#"..clr..">"..pn.."</rgb> @ "
				  if not rs then
				  	str = pi.rep
					  if DT_Settings.rep[pname][str] then
						  str = "<rgb=#FF0000>"..str.."</rgb>"
					  elseif DT_Settings.rep[pname][str]==false then
						  str = "<rgb=#FF00FF>"..str.."</rgb>"
					  end
					  str = "("..str..")"
				  else str = "" end
				  print(nbr..xname..pn..pi.loc..str)
			  end
		  end
		end
		return
    end
	local rc = args:upper()
	local rep = DT_Data.rep[rc]
	if rep then
		print(rc.." is "..rep)
		local s = ''
		for loc,tb in pairs(DT_Data.loc) do
			if tb.rep==rc then
				if s~='' then s = s..", " end
				s = s..loc
			end
		end
		local ln = {}
		for id,tb in pairs(DT_Data.id) do
			for loc,l in pairs(tb.L) do
				if type(l)=='table' and l.r==rc then ln[loc] = true end
			end
		end
		for loc in pairs(ln) do
			if s~='' then s = s..", " end
			s = s..loc
		end
		print("Task Board @ "..s)
		return
	else printe("Invalid rep code.") end
end

Turbine.Shell.AddCommand( "dtr",DTR_Command )

-- Daily Task players command

DTP_Command = Turbine.ShellCommand()

function DTP_Command:Execute( command,args )
	if args=="?" then Vinny.Common.Help(help,command) return end
    if args=="" then
        printh("Known player characters:")
        for i,name in ipairs(Vinny.Common.Sort(DT_Settings.player)) do
			local lvl = DT_Settings.player[name]
            print(string.format("%s: %s",name,lvl))
        end
        return
    end
    if args=="tc" then
        printh("Player tasks that may be completed:")
        for i,name in ipairs(Vinny.Common.Sort(DT_Settings.tasks)) do
			local cnt = DT_Settings.tasks[name]
            print(string.format("%s: %s",name,cnt))
        end
        return
    end
    if args=="names" then
		DT_Settings.names = not DT_Settings.names
		Turbine.PluginData.Save(Turbine.DataScope.Server,"DailyTasks_Settings",DT_Settings)
		local state = DT_Settings.names and "on" or "off"
		print("Player names turned "..state)
        return
    end
    if DT_Settings.player[args] then
    	print("Removing player name, "..args)
    	DT_Settings.player[args] = nil
    	DT_Settings.rep[args] = nil
    	Turbine.PluginData.Save(Turbine.DataScope.Server,"DailyTasks_Settings",DT_Settings)
        return
    end
	Vinny.Common.Help(help,command)
end

Turbine.Shell.AddCommand( "dtp",DTP_Command )
